// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  AngleListParameter.h                        XMM Science Analysis Subsystem
 *
 *  Angle-std::list task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleListParameter.h,v 1.6 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#ifndef ANGLELISTPARAMETER_H
#define ANGLELISTPARAMETER_H

#include "RealListParameter.h"
#include "AngleFormatter.h"


//================================================================
//  Class AngleListParameter
//================================================================

class AngleListParameter : public RealListParameter
{
public:

    // Construction
    AngleListParameter* clone() { return new AngleListParameter(*this); }
    AngleListParameter();

    // Value
    ParamType   getType() const {return Parameter::AngleList;}
    const char* getTypeName() const { return "angle"; }

    // Formatting
    AngleFormatter::AngleMode getMode() const { return _mode; }
    void setMode(AngleFormatter::AngleMode mode);

protected:

    // Parsing and formatting
    bool   parseDouble(const std::string& str, double& value, bool first);
    std::string doubleAsString(double value) const;

private:

    // Member data
    AngleFormatter::AngleMode _mode;};

#endif
