// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  AngleParameter.h                            XMM Science Analysis Subsystem
 *
 *  Angle task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleParameter.h,v 1.5 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#ifndef ANGLEPARAMETER_H
#define ANGLEPARAMETER_H

#include "RealParameter.h"
#include "AngleFormatter.h"

#include <string>


//================================================================
//  Class AngleParameter
//================================================================

class AngleParameter : public RealParameter
{
public:

    // Construction
    AngleParameter* clone() { return new AngleParameter(*this); }
    AngleParameter();

    // Value
    ParamType   getType() const {return Parameter::Angle;}
    const char* getTypeName() const { return "angle"; }

    // Formatting
    std::string      asString() const;
    std::string      defaultAsString() const;
    AngleFormatter::AngleMode getMode() const { return _mode; }
    void setMode(AngleFormatter::AngleMode mode);

private:

    // Parsing
    bool parse(const std::string& str, double& value);

    // Member data
    AngleFormatter::AngleMode _mode;
};

#endif
