// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  BoolListParameter.h                         XMM Science Analysis Subsystem
 *
 *  Boolean-std::list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolListParameter.h,v 1.14 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#ifndef BOOLLISTPARAMETER_H
#define BOOLLISTPARAMETER_H

#include "Parameter.h"           // SAS headers

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class BoolListParameter
//================================================================

class BoolListParameter : public Parameter
{
public:
    // Construction
    BoolListParameter* clone() { return new BoolListParameter(*this); }

    // Value
    std::vector<int>  boolListValue() const {return _value;}
    bool         setNewValue(const std::string& value);
    bool         setValue(const std::vector<int>& value);
    int          size() const;
    ParamType    getType() const {return Parameter::BoolList;}
    const char*  getTypeName() const { return "bool"; }

    // Default
    std::vector<int>  defaultValue() const {return _default;}
    bool         setNewDefault(const std::string& value);
    bool         setDefault(const std::vector<int>& value);
    void         revertToDefault();

    // Formatting
    std::string       asString() const;
    std::string       defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.boolListValue());}

    // Parsing
    bool parse(const std::string& str, std::vector<int>& value);

    // Validation
    bool isValid(const std::vector<int>& n) const;

    // Member data
    std::vector<int> _value;
    std::vector<int> _default;
};

#endif
