// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  BoolParameter.h                             XMM Science Analysis Subsystem
 *
 *  Boolean task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolParameter.h,v 1.9 2002/12/17 17:53:49 jbakker Exp $
 *
 *****************************************************************************/

#ifndef BOOLPARAMETER_H
#define BOOLPARAMETER_H

#include "Parameter.h"           // headers
#include <string>


//================================================================
//  Class BoolParameter
//================================================================

class BoolParameter : public Parameter
{
public:
    // Construction
    BoolParameter() : _value(false),_default(false) {}
    BoolParameter* clone() { return new BoolParameter(*this); }

    // Value
    bool      boolValue() const { return _value; }
    bool      setNewValue(const std::string& value);
    bool      setValue(bool value);
    ParamType getType() const {return Parameter::Bool;}
    const char* getTypeName() const { return "bool"; }

    // Default
    bool      defaultValue() const {return _default;}
    bool      setNewDefault(const std::string& value);
    bool      setDefault(bool value);
    void      revertToDefault();

    // Formatting
    std::string    asString() const;
    std::string    defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.boolValue());}
    

    // Parsing
    bool parse(const std::string& str, bool& value);

    // Member data
    bool _value;
    bool _default;
};

#endif
