// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  IntListParameter.h                          XMM Science Analysis Subsystem
 *
 *  Integer-std::list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntListParameter.h,v 1.11 2002/12/17 17:53:49 jbakker Exp $
 *
 *****************************************************************************/

#ifndef INTLISTPARAMETER_H
#define INTLISTPARAMETER_H

#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class IntListParameter
//================================================================

class IntListParameter : public Parameter
{
public:
    // Construction
    IntListParameter* clone() { return new IntListParameter(*this); }

    // Value
    std::vector<int>          intListValue() const {return _value;}
    bool                 setNewValue(const std::string& value);
    bool                 setValue(const std::vector<int>& value);
    int                  size() const;
    ParamType            getType() const {return Parameter::IntList;}
    const char*          getTypeName() const { return "int"; }

    // Default
    std::vector<int>          defaultValue() const {return _default;}
    bool                 setNewDefault(const std::string& value);
    bool                 setDefault(const std::vector<int>& value);
    void                 revertToDefault();

    // Fomatting
    std::string               asString() const;
    std::string               defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.intListValue());}

    // Parsing
    bool parse(const std::string& str, std::vector<int>& value);

    // Validation
    bool isValid(const std::vector<int>& n) const;
    void reportRangeError(const std::string& valueString);

    // Member data
    std::vector<int>   _value;
    std::vector<int>   _default;
};

#endif
