// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      ParamParser.h
// Author:    Jorgo Bakker (jbakker@rssd.esa.int)
// Generated: Mon Feb 10 12:28:59 CET 2003
// Usage:     -
// Info:      -

#ifndef ParamParser_h
#define ParamParser_h

#include <string>
class ParameterInfo;

/**
 * ParamParser is the abstract interface of all Parameter parsers.
 */
class ParamParser 
{
  
public:
  ParamParser(){}
  virtual ~ParamParser(){}
  
  /**
   * Loads the parameters from specified file
   * @param  nameOfFile specified name of file
   * @return            the collection of parameters found in the file.
   */
  virtual ParameterInfo* load(const std::string& nameOfFile)=0;

  /**
   * Saves the parameters to specified file
   * @param nameOfFile specified name of file
   * @param info       the collection of parameters ready for saving.
   */
  virtual void save(const ParameterInfo& info,const std::string& nameOfFile)=0;

private:
  ParamParser(const ParamParser&);      // copy constructor disabled!
  ParamParser& operator=(const ParamParser&); // assignment disabled!
};



#endif
