// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  StringListParameter.h                       XMM Science Analysis Subsystem
 *
 *  String-std::list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringListParameter.h,v 1.12 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef STRINGLISTPARAMETER_H
#define STRINGLISTPARAMETER_H

#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>
#include <list>


//================================================================
//  Class StringListParameter
//================================================================

class StringListParameter : public Parameter
{
public:
    // Construction
    StringListParameter* clone() { return new StringListParameter(*this); }

    // Value
    std::vector<std::string> stringListValue() const {return _value;}
    bool           setNewValue(const std::string& value);
    bool           setValue(const std::vector<std::string>& value);
    int            size() const;
    ParamType      getType() const {return Parameter::StringList;}
    const char*    getTypeName() const { return "string"; }

    // Default
    std::vector<std::string> defaultValue() const {return _default;}
    bool           setNewDefault(const std::string& value);
    bool           setDefault(const std::vector<std::string>& value);
    void           revertToDefault();

    // Fomatting
    std::string         asString() const;
    std::string         defaultAsString() const;

protected:

    // Parsing
    bool parse(const std::string& str, std::vector<std::string>& value);

    // Validation
    virtual bool isValid(const std::vector<std::string>& n) const;
    virtual void reportRangeError(const std::string& valueString);

    // Member data
    std::vector<std::string> _value;
    std::vector<std::string> _default;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.stringListValue());}

    std::list<std::string> splitStringList(const std::string& str);

    // Member data
    std::list<std::string> _choices;
};

#endif

