// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/**-*-C++-*-*******************************************************************
 *
 *  StringParameter.h                           XMM Science Analysis Subsystem
 *
 *  String task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringParameter.h,v 1.11 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef STRINGPARAMETER_H
#define STRINGPARAMETER_H

#include "Parameter.h"           // headers
#include <string>


//================================================================
//  Class StringParameter
//================================================================

class StringParameter : public Parameter
{
public:
    // Construction
    StringParameter* clone() { return new StringParameter(*this); }

    // Value
    const std::string&  stringValue() const { return _value; }
    bool           setNewValue(const std::string& value);
    virtual bool   setValue(const std::string& value);
    virtual bool   setValue(const char* s) { return setValue(std::string(s)); }
    ParamType      getType() const {return Parameter::String;}
    const char*    getTypeName() const { return "string"; }

    // Default
    const std::string&  defaultValue() const {return _default;}
    bool           setNewDefault(const std::string& value);
    virtual bool   setDefault(const std::string& value);
    void           revertToDefault();

    // Formatting
    virtual std::string asString() const;
    std::string     defaultAsString() const;

protected:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.stringValue());}

    // Parsing
    bool parse(const std::string& str, std::string& value);

    // Validation
    virtual bool isValid(const std::string& value) const;
    virtual void reportRangeError(const std::string& valueString);

    // Member data
    std::string _value;
    std::string _default;

};

#endif

