// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  TimeListParameter.h                         XMM Science Analysis Subsystem
 *
 *  Time-std::list task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeListParameter.h,v 1.6 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef TIMELISTPARAMETER_H
#define TIMELISTPARAMETER_H

#include "RealListParameter.h"
#include "TimeFormatter.h"

#include <vector>
#include <string>


//================================================================
//  Class TimeListParameter
//================================================================

class TimeListParameter : public RealListParameter
{
public:

    // Construction
    TimeListParameter* clone() { return new TimeListParameter(*this); }
    TimeListParameter();

    // Value
    ParamType   getType() const {return Parameter::TimeList;}
    const char* getTypeName() const { return "time"; }
    TimeFormatter::TimeMode getMode() const { return _mode; }
    void setMode(TimeFormatter::TimeMode mode);

protected:

    // Parsing and formatting
    bool        parseDouble(const std::string& str, double& value, bool first);
    std::string      doubleAsString(double value) const;

private:

    // Member data
    TimeFormatter::TimeMode _mode;
};

#endif
