// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  TimeParameter.h                            XMM Science Analysis Subsystem
 *
 *  Time task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeParameter.h,v 1.6 2002/12/17 17:53:51 jbakker Exp $
 *
 *****************************************************************************/

#ifndef TIMEPARAMETER_H
#define TIMEPARAMETER_H

#include "RealParameter.h"
#include "TimeFormatter.h"

#include <string>


//================================================================
//  Class TimeParameter
//================================================================

class TimeParameter : public RealParameter
{
public:

    // Construction
    TimeParameter* clone() { return new TimeParameter(*this); }
    TimeParameter();

    // Value
    ParamType   getType() const { return Parameter::Time; }
    const char* getTypeName() const { return "time"; }

    // Formatting
    std::string      asString() const;
    std::string      defaultAsString() const;
    TimeFormatter::TimeMode getMode() const { return _mode; }
    void setMode(TimeFormatter::TimeMode mode);

private:

    // Parsing
    bool parse(const std::string& str, double& value);

    // Member data
    TimeFormatter::TimeMode _mode;
};

#endif
