! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!+
! Module: param.f90
!
! Authors:  Marco Beijersbergen
!          
! Description: F90 task interface to parameter system
! 
! Comments: 
! 
! $Id: param.f90,v 1.11 1999/02/22 15:58:28 jbrumfit Exp $
!- 

module param

	use errorHandling
	use types

        implicit none

	interface

	! Return the number of parameters in the list
	integer function parameterCount( name )
		character(len=*), intent(in) :: name
	end function

	function booleanParameter( name, pos )
		character(len=*), intent(in) :: name
		integer, intent(in), optional :: pos

		logical :: booleanParameter
	end function

	function intParameter( name, pos )
		use types
		character(len=*), intent(in) :: name
		integer, intent(in), optional :: pos

		integer(kind=int32) :: intParameter
	end function

	function realParameter( name, pos )
		use types
		character(len=*), intent(in) :: name
		integer, intent(in), optional :: pos

		real(kind=double) :: realParameter
	end function

	function stringParameter( name, pos )
		character(len=*), intent(in) :: name
		integer, intent(in), optional :: pos

		character(len=1024) :: stringParameter
	end function

	! Metatask support
	subroutine openParameters(category)
		character(len=*), intent(in) :: category
	end subroutine

	subroutine closeParameters()
	end subroutine

	end interface

	interface setParameter

	subroutine setBooleanParameter( name, value )
		character(len=*), intent(in) :: name
		logical, intent(in) :: value
	end subroutine

	subroutine setIntParameter( name, value )
		use types
		character(len=*), intent(in) :: name
		integer(kind=int32), intent(in) :: value
	end subroutine

	subroutine setReal32Parameter( name, value )
		use types
		character(len=*), intent(in) :: name
		real(kind=single), intent(in) :: value
	end subroutine

	subroutine setReal64Parameter( name, value )
		use types
		character(len=*), intent(in) :: name
		real(kind=double), intent(in) :: value
	end subroutine

	subroutine setStringParameter( name, value )
		character(len=*), intent(in) :: name
		character(len=*), intent(in) :: value
	end subroutine

	subroutine setBooleanListParameter( name, value )
		character(len=*), intent(in) :: name
		logical, intent(in), dimension(:) :: value
	end subroutine

	subroutine setIntListParameter( name, value )
		use types
		character(len=*), intent(in) :: name
		integer(kind=int32), intent(in), dimension(:) :: value
	end subroutine

	subroutine setReal32ListParameter( name, value )
		use types
		character(len=*), intent(in) :: name
		real(kind=single), intent(in), dimension(:) :: value
	end subroutine

	subroutine setReal64ListParameter( name, value )
		use types
		character(len=*), intent(in) :: name
		real(kind=double), intent(in), dimension(:) :: value
	end subroutine

	subroutine setStringListParameter( name, value )
		character(len=*), intent(in) :: name
		character(len=*), intent(in), dimension(:) :: value
	end subroutine

	end interface

end module param


