// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  param.h                                     XMM Science Analysis Subsystem
 *
 *  C task interface to parameter system
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: param.h,v 1.29 2002/12/17 17:53:51 jbakker Exp $
 *
 *****************************************************************************/

#ifndef __param_h
#define __param_h

#include <string>                  // C++ headers

#include "XmlInfoReader.h"         // Application headers
#include "Parameter.h"
#include <errstr.h>


// Global parameter information

extern ParameterInfo* gParameters;


//================================================================
//  Public interface
//================================================================

/*** Return the number of elements for a std::list parameter ***/

int parameterCount(const std::string& name);


/*** Return value of boolean parameter "name" ***/

bool booleanParameter(const std::string& name, int pos=-1);

// Work-around for egcs compiler problem with vector<bool>
std::vector<int> boolListParameter(const std::string& name);


/*** Return value of integer parameter "name" ***/

int intParameter(const std::string& name, int pos=-1);

std::vector<int> intListParameter(const std::string& name);


/*** Return value of real parameter "name" ***/

double realParameter(const std::string& name, int pos=-1);

std::vector<double> realListParameter(const std::string& name);


/*** Return value of std::string parameter "name" ***/

std::string stringParameter(const std::string& name, int pos=-1);

std::vector<std::string> stringListParameter(const std::string& name);


/*** Set the value of a parameter ***/

template<class T>
void setParameter(const std::string& name, const T& value)
{
    Parameter* p = (*gParameters)[name];
    if(p) {
      if(!p->setValue(value))
	errstr << "Value out of range for parameter '"
	       << name << "'" << Sas::error("ParamNotInRange");
    } else
      errstr << "Parameter " << name << " not found" 
	     << Sas::error("ParamNotFound");
}

template<class T>
void setParameter(const char* name, const T& value)
{
    setParameter(std::string(name), value);
}


//================================================================
//  Used only by taskmain
//================================================================

/*** Open the parameter set for task "name" ***/

void openParameters(const std::string& name);


/*** Close the parameter set ***/

void closeParameters();

#endif
