// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/****************************************************************************
 *
 *  testapierror.cc                            XMM Science Analysis Subsystem
 *
 *  Test various errors in API calls
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testapierror.cc,v 1.6 2002/12/17 17:53:51 jbakker Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>

#include <cstdlib>                  // C headers

#include <iostream>                // C++ headers
#include <string>
#include <vector>

#include <errstr.h>

int main(int argc, char* argv[])
{
    // Get argument specifying test to be performed
    if(argc != 2)
    {
        std::cerr << "Testcmdline requires one argument" << std::endl;
        ::exit(1);
    }
    int testno = atoi(argv[1]);
    std::cout << argv[0] << " test " << testno << std::endl;

    std::string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters("testparamcc");

    switch(testno)
    {
    case 0:
        // Attempt to access non-existant parameter
        std::cout << intParameter("nonexistant") << std::endl;
	break;

    case 1:
        // Attempt to access parameter with wrong type
        std::cout << intParameter("sval") << std::endl;
	break;

    case 2:
        // Attempt to index a scalar parameter
        std::cout << intParameter("ival",2) << std::endl;
        break;
      
    case 3:
        // Attempt to sets parameter with incorrect type
        setParameter("ival",3.14);
        break;

    case 4:
        // Attempt to use out-of-range array index
        std::cout << intParameter("ilist",10) << std::endl;
        break;

    case 5:
        // Attempt to call parameterCount for a scalar parameter
        std::cout << parameterCount("ival") << std::endl;
        break;

    case 6:
        // Attempt to setParameter with out-of-range value
        setParameter("ival",200);
        break;

    case 7:
        // Attempt to set non-existant parameter
        setParameter("nonExistant",42);
        break;

    case 8: {
        // Attempt to access non-existant vector
        std::vector<int> vi1 = intListParameter("nonexistant");
	break;
    }
    case 9: {
        // Attempt to access vector with wrong type
        std::vector<int> vi2 = intListParameter("slist");
	break;
    }

    default:
        std::cerr << "Invalid test number = " << testno << std::endl;
        break;
    }

    closeParameters();

    return 0;
}
