! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
program testfsetparam
  use param
  use types

  call openParameters("testparamcc")

  ! Boolean parameter

  call setParameter("bval1",.false.)
  if (booleanParameter("bval1")) &
    call error("setParameter boolean","invalid value for bval1")

  call setParameter("bval1",.true.)
  if (.not. booleanParameter("bval1")) &
    call error("setParameter boolean","invalid value for bval1")

  ! Integer parameter

  call setParameter("ival",27)
  if (intParameter("ival") /= 27) &
    call error("setParameter int","invalid value for ival")

  ! Real parameter

  call setParameter("rval",2.718_double)
  if (realParameter("rval") /= 2.718_double) &
    call error("setParameter real","invalid value for rval")

  call setParameter("rval",3.142_single)
  if (realParameter("rval") /= 3.142) &
    call error("setParameter real","invalid value for rval")
  
  ! String parameter

  call setParameter("sval","hello world")
  if (stringParameter("sval") /= "hello world") &
    call error("setParameter string","invalid value for sval")

  call setParameter("sval","foo bar")
  if (stringParameter("sval") /= "foo bar") &
    call error("setParameter string","invalid value for sval")

  ! Boolean list parameter

  call setParameter("blist", (/.false.,.true./) )
  if(parameterCount("blist") /= 2) &
    call error("setParameter list(bool)","invalid length for blist")
  write(*,*) booleanParameter("blist",0)
  if (booleanParameter("blist",0)) &
    call error("setParameter list(bool)","invalid value for blist(0)")
  if (.not. booleanParameter("blist",1)) &
    call error("setParameter list(bool)","invalid value for blist(1)")

  ! Integer list parameter

  call setParameter("ilist", (/1,-3,5/) )
  if(parameterCount("ilist") /= 3) &
    call error("setParameter list(int)","invalid length for ilist")
  if (intParameter("ilist",0) /= 1) &
    call error("setParameter list(int)","invalid value for ilist(0)")
  if (intParameter("ilist",1) /= -3) &
    call error("setParameter list(int)","invalid value for ilist(1)")
  if (intParameter("ilist",2) /= 5) &
    call error("setParameter list(int)","invalid value for ilist(2)")

  ! Real list parameter

  call setParameter("rlist", (/1.2,3.2E3,5.7E-1/) )
  if(parameterCount("rlist") /= 3) &
    call error("setParameter list(real)","invalid length for rlist")
  if (realParameter("rlist",0) /= 1.2) &
    call error("setParameter list(real)","invalid value for rlist(0)")
  if (realParameter("rlist",1) /= 3.2E3) &
    call error("setParameter list(real)","invalid value for rlist(1)")
  if (realParameter("rlist",2) /= 5.7E-1) &
    call error("setParameter list(real)","invalid value for rlist(2)")

  call setParameter("rlist", (/2.3_double,4.5_double/) )
  if(parameterCount("rlist") /= 2) &
    call error("setParameter list(real)","invalid length for rlist")
  if (realParameter("rlist",0) /= 2.3_double) &
    call error("setParameter list(real)","invalid value for rlist(0)")
  if (realParameter("rlist",1) /= 4.5_double) &
    call error("setParameter list(real)","invalid value for rlist(1)")

  ! String list parameter

  if(parameterCount("slist") /= 3) &
    call error("setParameter list(string)","invalid length for slist")
  call setParameter("slist", (/"aa","ab","ac","ad"/) )
  if (stringParameter("slist",0) /= "aa") &
    call error("setParameter list(string)","invalid value for slist(0)")
  if (stringParameter("slist",1) /= "ab") &
    call error("setParameter list(string)","invalid value for slist(1)")
  if (stringParameter("slist",2) /= "ac") &
    call error("setParameter list(string)","invalid value for slist(2)")

end program
