// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Simple test harness for the C bindings to the parameter interface.
//
// TODO:
//   - test failure/success
//   - set parameters
//   - list parameters
//
// Giuseppe Vacanti -- March 30, 1999
//
#include <Parameter.h>
#include <param.h>
#include <paramc.h>

#include <errstr.h>
#include <cassert>
#include <cstring>

int main(int argc, char* argv[])
{

    std::string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters(taskname);
    gParameters->parseCommandLine(argc,argv);

    // single parameters
    std::cout << "---> single parameters <---" << std::endl;

    std::cout << "ival = " << int_parameter("ival", -1) << std::endl;
    assert(int_parameter("ival", -1) == 42);

    std::cout << "rval = " << real_parameter("rval", -1) << std::endl;
    assert(real_parameter("rval", -1) == 1.23e-5);

    std::cout << "sval = " << string_parameter("sval", -1) << std::endl;
    assert(strcmp(string_parameter("sval", -1),"ab #,cd") == 0);

    std::cout << "bval0 = " << boolean_parameter("bval0", -1) << std::endl;
    assert(boolean_parameter("bval0", -1) == false);

    std::cout << "bval1 = " << boolean_parameter("bval1", -1) << std::endl;
    assert(boolean_parameter("bval1", -1) == true);

    std::cout << "fval = " << string_parameter("fval", -1) << std::endl;
    assert(strcmp(string_parameter("fval", -1), "temp") == 0);

    std::cout << "set = " << string_parameter("set", -1) << std::endl;
    assert(strcmp(string_parameter("set", -1), "temp") == 0);

    // list parameters
    std::cout << "---> std::list parameters <---" << std::endl;

    std::cout << "blist -> " << parameter_count("blist") << std::endl;
    for (int i = 0; i < parameter_count("blist");)
      std::cout << boolean_parameter("blist", i++) << std::endl;

    std::cout << "ilist -> " << parameter_count("ilist") << std::endl;
    for (int i = 0; i < parameter_count("ilist");)
      std::cout << int_parameter("ilist", i++) << std::endl;

    std::cout << "rlist -> " << parameter_count("rlist") << std::endl;
    for (int i = 0; i < parameter_count("rlist");)
      std::cout << real_parameter("rlist", i++) << std::endl;

    std::cout << "slist -> " << parameter_count("slist") << std::endl;
    for (int i = 0; i < parameter_count("slist");)
      std::cout << string_parameter("slist", i++) << std::endl;

    std::cout << "clist -> " << parameter_count("clist") << std::endl;
    for (int i = 0; i < parameter_count("clist");)
      std::cout << string_parameter("clist", i++) << std::endl;

    std::cout << "flist -> " << parameter_count("flist") << std::endl;
    for (int i = 0; i < parameter_count("flist");)
      std::cout << string_parameter("flist", i++) << std::endl;

    std::cout << "setlist -> " << parameter_count("setlist") << std::endl;
    for (int i = 0; i < parameter_count("setlist");)
      std::cout << string_parameter("setlist", i++) << std::endl;


}

  
