// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/****************************************************************************
 *
 *  testparamfileerror.cc                      XMM Science Analysis Subsystem
 *
 *  Test handling of parameter file errors
 *
 *  Usage: testparmfileerror <parfile>
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testparamfileerror.cc,v 1.5 2009/07/02 17:43:38 eojero Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>

#include <iostream>                // C++ headers
#include <string>

#include <errstr.h>
#include <cstdlib>

int main(int argc, char* argv[])
{
    // Get argument specifying name of parameter file
    if(argc != 2)
    {
        std::cerr << "Testcmdline requires one argument" << std::endl;
	::exit(1);
    }

    // Strip ".par" extension from file-name, if present
    std::string parfile = argv[1];
    std::string::size_type i = parfile.find(".par");
    if(i != std::string::npos)
        parfile.replace(i,4,"");

    std::string taskname(argv[0]);
    errHandler.name(taskname);

    // Try reading parameter file
    openParameters(parfile);

    // Print parameter info for debugging
    std::cout << std::endl << "Parameter info:" << std::endl 
	 << *gParameters << std::endl;

    closeParameters();

    return 0;
}
