// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/****************************************************************************
 *
 *  testsetparam.cc                            XMM Science Analysis Subsystem
 *
 *  Test setting of parameters by task
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testsetparam.cc,v 1.14 2009/07/02 17:43:38 eojero Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>
#include <cassert>

#include <cmath>                    // C headers

#include <iostream>                // C++ headers
#include <string>
#include <vector>

#include <errstr.h>

int main()
{
    const double epsilon = 1e-5;

    openParameters("testparamcc");


    /*** Print intial values of parameters ***/

    std::cout << std::endl << "Parameters before:" << std::endl 
	 << *gParameters << std::endl;

    
    /*** Boolean parameter ***/

    setParameter("bval1", false);
    bool bval1 = booleanParameter("bval1");
    assert(bval1 == false);
    setParameter("bval1", true);
    bval1 = booleanParameter("bval1");
    assert(bval1 == true);


    /*** Integer parameter ***/

    setParameter("ival", 27);
    int ival = intParameter("ival");
    assert(ival == 27);


    /*** Real parameter ***/

    setParameter("rval", double(2.718));
    double rval1 = realParameter("rval");
    assert(fabs(rval1 - 2.718) < 2.718 * epsilon);

    
    /*** String parameter ***/

    setParameter("sval", "hello world");
    std::string sval = stringParameter("sval");
    assert(sval == "hello world");

    const char* sval1 = "foo bar";
    setParameter("sval",sval1);
    sval = stringParameter("sval");
    assert(sval == "foo bar");

    
     /*** Boolean parameter std::list ***/

    // Work-around for egcs compiler bug with vector<bool>
    std::vector<int> vb;
    vb.push_back(true);
    vb.push_back(false);
    setParameter("blist", vb);
    assert(parameterCount("blist") == 2);
    bool b0 = booleanParameter("blist", 0);
    assert(b0 == true);
    bool b1 = booleanParameter("blist", 1);
    assert(b1 == false);


   /*** Integer parameter std::list ***/

    std::vector<int> vi;
    vi.push_back(1);
    vi.push_back(-3);
    vi.push_back(5);
    setParameter("ilist", vi);
    assert(parameterCount("ilist") == 3);
    int i0 = intParameter("ilist", 0);
    assert(i0 == 1);
    int i1 = intParameter("ilist", 1);
    assert(i1 == -3);
    int i2 = intParameter("ilist", 2);
    assert(i2 == 5);
 

   /*** Real parameter std::list ***/

    std::vector<double> vr;
    vr.push_back(1.2);
    vr.push_back(3.2e3);
    vr.push_back(5.7e-1);
    setParameter("rlist", vr);
    assert(parameterCount("rlist") == 3);
    double r0 = realParameter("rlist", 0);
    assert(r0 == 1.2);
    double r1 = realParameter("rlist", 1);
    assert(r1 == 3.2e3);
    double r2 = realParameter("rlist", 2);
    assert(r2 == 5.7e-1);
 

    /*** String parameter std::list ***/

    std::vector<std::string> vs;
    vs.push_back("xy z");
    vs.push_back("ab");
    setParameter("slist", vs);
    assert(parameterCount("slist") == 2);
    std::string s0 = stringParameter("slist", 0);
    assert(s0 == "xy z");
    std::string s1 = stringParameter("slist", 1);
    assert(s1 == "ab");


    /*** Print final values of parameters ***/

    std::cout << std::endl << "Parameter after:" << std::endl 
	 << *gParameters << std::endl;

    closeParameters();

    return 0;
}
